require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_processmitigation',
  dscmeta_resource_friendly_name: 'ProcessMitigation',
  dscmeta_resource_name: 'ProcessMitigation',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'WindowsDefenderDsc',
  dscmeta_module_version: '2.2.0',
  docs: 'The DSC ProcessMitigation resource type.
         Automatically generated from version 2.2.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_mitigationvalue: {
      type: "Enum['true', 'false']",
      desc: 'Mitigation Value',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mitigationtype: {
      type: "Enum['ControlFlowGuard', 'SystemCalls', 'StrictHandle', 'DynamicCode', 'PayLoad', 'ASLR', 'Heap', 'Fonts', 'SignedBinaries', 'ImageLoad', 'SEHOP', 'ExtensionPoints', 'DEP', 'ChildProcess']",
      desc: 'Type of mitigation setting',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mitigationtarget: {
      type: 'String',
      desc: 'Name of the process to apply mitigation settings to. Use System to configure system defaults rather than individual app',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_mitigationname: {
      type: "Enum['HighEntropy', 'OverrideHighEntropy', 'BottomUp', 'OverrideForceRelocateImages', 'RequireInfo', 'ForceRelocateImages', 'OverrideBottomUp', 'AllowStoreSignedBinaries', 'AuditMicrosoftSignedOnly', 'OverrideMicrosoftSignedOnly', 'AuditEnforceModuleDependencySigning', 'AuditStoreSigned', 'OverrideDependencySigning', 'MicrosoftSignedOnly', 'EnforceModuleDependencySigning', 'StrictControlFlowGuard', 'OverrideCFG', 'OverrideStrictCFG', 'Enable', 'SuppressExports', 'OverrideChildProcess', 'DisallowChildProcessCreation', 'Audit', 'EmulateAtlThunks', 'OverrideDEP', 'OverrideDynamicCode', 'BlockDynamicCode', 'AllowThreadsToOptOut', 'DisableExtensionPoints', 'OverrideExtensionPoint', 'OverrideFontDisable', 'DisableNonSystemFonts', 'TerminateOnError', 'OverrideHeap', 'OverrideBlockLowLabel', 'OverridePreferSystem32', 'OverrideBlockRemoteImageLoads', 'AuditPreferSystem32', 'PreferSystem32', 'AuditLowLabelImageLoads', 'BlockLowLabelImageLoads', 'AuditRemoteImageLoads', 'BlockRemoteImageLoads', 'EAFModules', 'AuditEnableExportAddressFilterPlus', 'EnableRopStackPivot', 'EnableExportAddressFilter', 'OverrideEnableRopStackPivot', 'AuditEnableRopCallerCheck', 'OverrideEnableRopCallerCheck', 'AuditEnableRopStackPivot', 'OverrideEnableImportAddressFilter', 'OverrideEnableExportAddressFilter', 'EnableExportAddressFilterPlus', 'AuditEnableRopSimExec', 'AuditEnableImportAddressFilter', 'OverrideEnableRopSimExec', 'EnableRopCallerCheck', 'AuditEnableExportAddressFilter', 'EnableRopSimExec', 'EnableImportAddressFilter', 'OverrideEnableExportAddressFilterPlus', 'TelemetryOnly', 'OverrideSEHOP', 'OverrideStrictHandle', 'DisableWin32kSystemCalls', 'OverrideSystemCall']",
      desc: 'Mitigation Name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
